@@ -1,7 +1,9 @@
 from .augmentations.background_noise import AddBackgroundNoise
 from .augmentations.colored_noise import AddColoredNoise
 from .augmentations.gain import Gain
+from .augmentations.high_pass_filter import HighPassFilter
 from .augmentations.impulse_response import ApplyImpulseResponse
+from .augmentations.low_pass_filter import LowPassFilter
 from .augmentations.peak_normalization import PeakNormalization
 from .augmentations.polarity_inversion import PolarityInversion
 from .augmentations.shift import Shift
@@ -10,4 +12,4 @@ from .core.composition import Compose
 from .utils.config import from_dict, from_yaml
 from .utils.convolution import convolve
 
-__version__ = "0.7.0"
+__version__ = "0.8.0"
